@@ -9,7 +9,7 @@
     <message>
         <location filename="mainwindow.ui" line="39"/>
         <source>Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
-        <translation type="unfinished"/>
+        <translation>Oprava zavaděče je nástroj, který lze použít k opětovné instalaci bootloaderu GRUB na ESP (EFI System Partition), MBR (Master Boot Record) nebo kořenový oddíl. Poskytuje možnost rekonstrukce konfiguračního souboru GRUB, zálohování a obnovení MBR nebo PBR (root).</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="58"/>
@@ -24,7 +24,7 @@
     <message>
         <location filename="mainwindow.ui" line="86"/>
         <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
-        <translation type="unfinished"/>
+        <translation>Přeinstalovat zavaděč GRUB na ESP, MBR nebo PBR (root)</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="96"/>
@@ -85,7 +85,7 @@
         <location filename="mainwindow.ui" line="277"/>
         <location filename="mainwindow.cpp" line="496"/>
         <source>Select root location:</source>
-        <translation type="unfinished"/>
+        <translation>Vyberte kořenové umístení:</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="290"/>
@@ -151,7 +151,7 @@
     <message>
         <location filename="mainwindow.cpp" line="86"/>
         <source>GRUB is being installed on %1 device.</source>
-        <translation type="unfinished"/>
+        <translation>GRUB se instaluje na zařízení %1.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="118"/>
@@ -176,12 +176,12 @@ Prosím zkontrolujte vybrané umístnění.</translation>
     <message>
         <location filename="mainwindow.cpp" line="179"/>
         <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
-        <translation type="unfinished"/>
+        <translation>Konfigurační soubor GRUB (grub.cfg) se znovu sestavuje.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="222"/>
         <source>Backing up MBR or PBR from %1 device.</source>
-        <translation type="unfinished"/>
+        <translation>Zálohování MBR nebo PBR ze zařízení %1.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="287"/>
@@ -210,7 +210,7 @@ Jste si jistí?</translation>
     <message>
         <location filename="mainwindow.cpp" line="293"/>
         <source>Restoring MBR/PBR from backup to %1 device.</source>
-        <translation type="unfinished"/>
+        <translation>Obnova MBR/PBR ze zálohy na zařízení %1.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="313"/>
@@ -220,7 +220,7 @@ Jste si jistí?</translation>
     <message>
         <location filename="mainwindow.cpp" line="348"/>
         <source>Select %1 location:</source>
-        <translation type="unfinished"/>
+        <translation>Vybrat umístění %1:</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="372"/>
@@ -245,27 +245,27 @@ Jste si jistí?</translation>
     <message>
         <location filename="mainwindow.cpp" line="412"/>
         <source>Enter password to unlock %1 encrypted partition:</source>
-        <translation type="unfinished"/>
+        <translation>Zapsat heslo pro odemčení šifrovaného oddílu %1:</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="420"/>
         <source>Sorry, could not open %1 LUKS container</source>
-        <translation type="unfinished"/>
+        <translation>Omlouváme se, nelze otevřít LUKS kontejner %1</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="495"/>
         <source>Select GRUB location</source>
-        <translation type="unfinished"/>
+        <translation>Vybrat umístění GRUB</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="507"/>
         <source>Select Item to Back Up</source>
-        <translation type="unfinished"/>
+        <translation>Vyberte položku k záloze</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="514"/>
         <source>Select Item to Restore</source>
-        <translation type="unfinished"/>
+        <translation>Vyberte položku k obnově</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="525"/>
@@ -286,7 +286,7 @@ Jste si jistí?</translation>
     <message>
         <location filename="mainwindow.cpp" line="552"/>
         <source>About %1</source>
-        <translation type="unfinished"/>
+        <translation>O %1</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="553"/>
@@ -306,17 +306,17 @@ Jste si jistí?</translation>
     <message>
         <location filename="mainwindow.cpp" line="557"/>
         <source>%1 License</source>
-        <translation type="unfinished"/>
+        <translation>Licence %1</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="571"/>
         <source>%1 Help</source>
-        <translation type="unfinished"/>
+        <translation>Nápověda %1</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="598"/>
         <source>Sorry, could not mount %1 partition</source>
-        <translation type="unfinished"/>
+        <translation>Omlouváme se, nelze připojit oddíl %1</translation>
     </message>
 </context>
 <context>
@@ -330,7 +330,7 @@ Jste si jistí?</translation>
         <location filename="about.cpp" line="33"/>
         <location filename="about.cpp" line="43"/>
         <source>Changelog</source>
-        <translation type="unfinished"/>
+        <translation>Protokol změn</translation>
     </message>
     <message>
         <location filename="about.cpp" line="34"/>
